@@ -229,6 +229,9 @@ class FacetProperties(RABase):
     """
 
     user_key: str = Field(alias="brugervendtnoegle", description="Short, unique key.")
+    description: Optional[str] = Field(
+        alias="beskrivelse", description="The facet description."
+    )
     effective_time: EffectiveTime = Field(
         alias="virkning", description="Effective time of the property."
     )
@@ -512,6 +515,7 @@ class KlasseProperties(RABase):
     effective_time: EffectiveTime = Field(
         alias="virkning", description="Effective time of the properties."
     )
+    example: Optional[str] = Field(alias="eksempel", description="Example usage.")
 
 
 class KlasseRelations(RABase):
@@ -534,6 +538,10 @@ class KlasseRelations(RABase):
         max_items=1,
         description="The parent class object.",
     )
+    owner: Optional[UUID] = Field(
+        alias="ejer",
+        description="Owner of class relation",
+    )
 
 
 class KlasseAttributes(RABase):
