@@ -12,10 +12,12 @@ from uuid import UUID
 
 from pydantic import Field
 
+from .._shared import EmployeeRef
 from .._shared import EngagementAssociationType
 from .._shared import EngagementRef
 from .._shared import EngagementType
 from .._shared import JobFunction
+from .._shared import LeaveRef
 from .._shared import MOBase
 from .._shared import OrgUnitRef
 from .._shared import PersonRef
@@ -33,8 +35,10 @@ class EngagementBase(MOBase):
     type_: str = Field("engagement", alias="type", description="The object type.")
     validity: Validity = Field(description="Validity of the engagement object.")
     fraction: Optional[int] = Field(
-        description="Indication of contribution to the "
-        "collection of engagements for the given employee."
+        description=(
+            "Indication of contribution to the "
+            "collection of engagements for the given employee."
+        )
     )
     extension_1: Optional[str] = Field(description="Optional extra information.")
     extension_2: Optional[str] = Field(description="Optional extra information.")
@@ -51,17 +55,22 @@ class EngagementBase(MOBase):
 class EngagementRead(EngagementBase):
     """A MO engagement read object."""
 
-    org_unit: UUID = Field(
+    org_unit_uuid: UUID = Field(
         description="UUID of the organisation unit related to the engagement."
     )
-    person: UUID = Field(description="UUID of the person related to the engagement.")
-    engagement_type: UUID = Field(
+    employee_uuid: UUID = Field(
+        description="UUID of the employee related to the engagement."
+    )
+    engagement_type_uuid: UUID = Field(
         description="UUID of the engagement type klasse of the engagement."
     )
-    job_function: UUID = Field(
+    job_function_uuid: UUID = Field(
         description="UUID of the job function klasse of the engagement."
     )
-    primary: Optional[UUID] = Field(
+    leave_uuid: Optional[UUID] = Field(
+        description="UUID of the leave related to the engagement."
+    )
+    primary_uuid: Optional[UUID] = Field(
         description="UUID of the primary klasse of the engagement."
     )
     is_primary: Optional[bool] = Field(
@@ -73,23 +82,31 @@ class EngagementWrite(EngagementBase):
     """A MO engagement write object."""
 
     org_unit: OrgUnitRef = Field(
-        description="Reference to the organisation unit "
-        "for which the engagement should be created."
+        description=(
+            "Reference to the organisation unit "
+            "for which the engagement should be created."
+        )
     )
-    person: PersonRef = Field(
-        description="Reference to the person "
-        "for which the engagement should be created."
+    employee: EmployeeRef = Field(
+        description=(
+            "Reference to the employee for which the engagement should be created."
+        )
     )
     engagement_type: EngagementType = Field(
-        description="Reference to the engagement type klasse "
-        "for the created engagement object."
+        description=(
+            "Reference to the engagement type klasse for the created engagement object."
+        )
     )
     # NOTE: Job function is set to optional in the current MO write code,
     # but that's an error. If payloads without a job function are posted,
     # MO fails spectacularly when reading the resulting engagement objects.
     job_function: JobFunction = Field(
-        description="Reference to the job function klasse "
-        "for the created engagement object."
+        description=(
+            "Reference to the job function klasse for the created engagement object."
+        )
+    )
+    leave: Optional[LeaveRef] = Field(
+        description="Reference to the leave for the created engagement."
     )
     primary: Optional[Primary] = Field(
         description="Reference to the primary klasse for the created engagement object."
@@ -103,20 +120,25 @@ class Engagement(MOBase):
         "engagement", alias="type", description="The object type."
     )
     org_unit: OrgUnitRef = Field(
-        description="Reference to the organisation unit "
-        "for which the engagement should be created."
+        description=(
+            "Reference to the organisation unit "
+            "for which the engagement should be created."
+        )
     )
     person: PersonRef = Field(
-        description="Reference to the person "
-        "for which the engagement should be created."
+        description=(
+            "Reference to the person for which the engagement should be created."
+        )
     )
     job_function: JobFunction = Field(
-        description="Reference to the job function klasse "
-        "for the created engagement object."
+        description=(
+            "Reference to the job function klasse for the created engagement object."
+        )
     )
     engagement_type: EngagementType = Field(
-        description="Reference to the engagement type klasse "
-        "for the created engagement object."
+        description=(
+            "Reference to the engagement type klasse for the created engagement object."
+        )
     )
     validity: Validity = Field(description="Validity of the created engagement object.")
     primary: Primary = Field(
@@ -137,7 +159,6 @@ class Engagement(MOBase):
     @classmethod
     def from_simplified_fields(
         cls,
-        uuid: UUID,
         org_unit_uuid: UUID,
         person_uuid: UUID,
         job_function_uuid: UUID,
@@ -146,6 +167,7 @@ class Engagement(MOBase):
         user_key: str,
         from_date: str,
         to_date: Optional[str] = None,
+        uuid: Optional[UUID] = None,
         extension_1: Optional[str] = None,
         extension_2: Optional[str] = None,
         extension_3: Optional[str] = None,
@@ -193,16 +215,22 @@ class EngagementAssociation(MOBase):
         "engagement_association", alias="type", description="The object type."
     )
     org_unit: OrgUnitRef = Field(
-        description="Reference to the organisation unit "
-        "for which the engagement association should be created."
+        description=(
+            "Reference to the organisation unit "
+            "for which the engagement association should be created."
+        )
     )
     engagement: EngagementRef = Field(
-        description="Reference to the engagement "
-        "for which the engagement association should be created."
+        description=(
+            "Reference to the engagement "
+            "for which the engagement association should be created."
+        )
     )
     engagement_association_type: EngagementAssociationType = Field(
-        description="Reference to the engagement association type klasse "
-        "for the created engagement association object."
+        description=(
+            "Reference to the engagement association type klasse "
+            "for the created engagement association object."
+        )
     )
     validity: Validity = Field(
         description="Validity of the created engagement association."
@@ -211,12 +239,12 @@ class EngagementAssociation(MOBase):
     @classmethod
     def from_simplified_fields(
         cls,
-        uuid: UUID,
         org_unit_uuid: UUID,
         engagement_uuid: UUID,
         engagement_association_type_uuid: UUID,
         from_date: str,
         to_date: Optional[str] = None,
+        uuid: Optional[UUID] = None,
     ) -> "EngagementAssociation":
         """Create an engagement association from simplified fields."""
         validity = Validity(from_date=from_date, to_date=to_date)
