@@ -55,6 +55,9 @@ class ITUserRead(ITUserBase):
     org_unit_uuid: Optional[UUID] = Field(
         description="UUID organisation unit related to the user."
     )
+    primary_uuid: Optional[UUID] = Field(
+        description="UUID of an associated `primary_type` class."
+    )
 
 
 class ITUserWrite(ITUserBase):
